@@ -16,7 +16,7 @@
  * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
  */
 
-package org.altusmetrum.altoslib_12;
+package org.altusmetrum.altoslib_13;
 
 import java.util.*;
 import java.text.*;
@@ -201,6 +201,8 @@ public class AltosConfigData {
 		case AltosLib.AO_LOG_FORMAT_TELEMEGA:
 		case AltosLib.AO_LOG_FORMAT_TELEMEGA_3:
 			return 4095 - value;
+		case AltosLib.AO_LOG_FORMAT_EASYMEGA_2:
+			return -value;
 		default:
 			return AltosLib.MISSING;
 		}
@@ -581,6 +583,22 @@ public class AltosConfigData {
 		throw new AltosUnknownProduct(product);
 	}
 
+	public boolean adxl375_inverted() throws AltosUnknownProduct {
+		if (product != null) {
+			if (product.startsWith("EasyMega-v2"))
+				return true;
+		}
+		throw new AltosUnknownProduct(product);
+	}
+
+	public int adxl375_axis() throws AltosUnknownProduct {
+		if (product != null) {
+			if (product.startsWith("EasyMega-v2"))
+				return AltosAdxl375.X_AXIS;
+		}
+		throw new AltosUnknownProduct(product);
+	}
+
 	public void get_values(AltosConfigValues source) throws AltosConfigDataException {
 
 		/* HAS_FLIGHT */
