@@ -19,7 +19,7 @@
 /*
  * Sensor data conversion functions
  */
-package org.altusmetrum.altoslib_12;
+package org.altusmetrum.altoslib_13;
 
 import java.util.*;
 
@@ -258,12 +258,18 @@ public class AltosConvert {
 		return sensor / 32767.0 * supply * 127/27;
 	}
 
-	static double tele_gps_voltage(int sensor) {
+	static double tele_gps_1_voltage(int sensor) {
 		double	supply = 3.3;
 
 		return sensor / 32767.0 * supply * (5.6 + 10.0) / 10.0;
 	}
 
+	static double tele_gps_2_voltage(int sensor) {
+		double	supply = 3.3;
+
+		return sensor / 4095.0 * supply * (5.6 + 10.0) / 10.0;
+	}
+
 	static double tele_bt_3_battery(int raw) {
 		if (raw == AltosLib.MISSING)
 			return AltosLib.MISSING;
