@@ -16,8 +16,12 @@
  * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
  */
 
-package org.altusmetrum.altoslib_12;
+package org.altusmetrum.altoslib_13;
 
 public interface AltosFlashListener {
+
+	public final static String flash_start = "start";
+	public final static String flash_done = "done";
+
 	public void position(String label, int percent);
 }
