@@ -16,7 +16,7 @@
  * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
  */
 
-package org.altusmetrum.altoslib_12;
+package org.altusmetrum.altoslib_13;
 
 public class AltosHexsym {
 	String	name;
@@ -24,8 +24,12 @@ public class AltosHexsym {
 
 	final static long invalid_addr = 0xffffffff;
 
+	public String toString() {
+		return String.format("%s:0x%x", name, address);
+	}
+
 	public AltosHexsym(String name, long address) {
 		this.name = name;
 		this.address = address;
 	}
-}
\ No newline at end of file
+}
