@@ -16,7 +16,7 @@
  * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
  */
 
-package org.altusmetrum.altoslib_12;
+package org.altusmetrum.altoslib_13;
 
 import java.io.*;
 import java.util.*;
@@ -32,7 +32,7 @@ class AltosIdler {
 	static final int	idle_mag = 2;
 	static final int	idle_mma655x = 4;
 	static final int	idle_ms5607 = 5;
-
+	static final int	idle_adxl375 = 6;
 
 	static final int	idle_sensor_tm = 10;
 	static final int	idle_sensor_metrum = 11;
@@ -40,8 +40,9 @@ class AltosIdler {
 	static final int	idle_sensor_emini1 = 13;
 	static final int	idle_sensor_emini2 = 14;
 	static final int	idle_sensor_tmini2 = 15;
-	static final int	idle_sensor_tgps = 16;
-	static final int	idle_sensor_tmini3 = 17;
+	static final int	idle_sensor_tgps1 = 16;
+	static final int	idle_sensor_tgps2 = 17;
+	static final int	idle_sensor_tmini3 = 18;
 
 	public void provide_data(AltosDataListener listener, AltosLink link) throws InterruptedException, TimeoutException, AltosUnknownProduct {
 		for (int idler : idlers) {
@@ -58,6 +59,9 @@ class AltosIdler {
 			case idle_mma655x:
 				AltosMma655x.provide_data(listener, link);
 				break;
+			case idle_adxl375:
+				AltosAdxl375.provide_data(listener, link);
+				break;
 			case idle_ms5607:
 				AltosMs5607.provide_data(listener, link);
 				break;
@@ -79,8 +83,11 @@ class AltosIdler {
 			case idle_sensor_tmini2:
 				AltosSensorTMini2.provide_data(listener, link);
 				break;
-			case idle_sensor_tgps:
-				AltosSensorTGPS.provide_data(listener, link);
+			case idle_sensor_tgps1:
+				AltosSensorTGPS1.provide_data(listener, link);
+				break;
+			case idle_sensor_tgps2:
+				AltosSensorTGPS2.provide_data(listener, link);
 				break;
 			case idle_sensor_tmini3:
 				AltosSensorTMini3.provide_data(listener, link);
@@ -157,14 +164,22 @@ public class AltosIdleFetch implements AltosDataProvider {
 			       AltosIdler.idle_ms5607,
 			       AltosIdler.idle_imu,
 			       AltosIdler.idle_sensor_mega),
-		new AltosIdler("EasyMega",
+		new AltosIdler("EasyMega-v1",
 			       AltosIdler.idle_mma655x,
 			       AltosIdler.idle_ms5607,
 			       AltosIdler.idle_imu, AltosIdler.idle_mag,
 			       AltosIdler.idle_sensor_mega),
-		new AltosIdler("TeleGPS",
+		new AltosIdler("EasyMega-v2",
+			       AltosIdler.idle_adxl375,
+			       AltosIdler.idle_ms5607,
+			       AltosIdler.idle_imu,
+			       AltosIdler.idle_sensor_mega),
+		new AltosIdler("TeleGPS-v1",
 			       AltosIdler.idle_gps,
-			       AltosIdler.idle_sensor_tgps),
+			       AltosIdler.idle_sensor_tgps1),
+		new AltosIdler("TeleGPS-v2",
+			       AltosIdler.idle_gps,
+			       AltosIdler.idle_sensor_tgps2),
 	};
 
 	AltosLink		link;
