@@ -16,7 +16,7 @@
  * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
  */
 
-package org.altusmetrum.altoslib_12;
+package org.altusmetrum.altoslib_13;
 
 import java.io.*;
 
@@ -28,7 +28,7 @@ public abstract class AltosProgrammer {
 
 	abstract public void abort();
 
-	abstract public AltosRomconfig target_romconfig() throws InterruptedException;
+	abstract public AltosRomconfig target_romconfig(AltosUsbId usb_id, String usb_product) throws InterruptedException;
 
 	abstract public AltosRomconfig image_romconfig();
 
