@@ -16,10 +16,11 @@
  * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
  */
 
-package org.altusmetrum.altosuilib_12;
+package org.altusmetrum.altosuilib_13;
 
 import java.util.*;
 import libaltosJNI.*;
+import org.altusmetrum.altoslib_13.*;
 
 public class AltosUSBDevice  extends altos_device implements AltosDevice {
 
@@ -94,6 +95,32 @@ public class AltosUSBDevice  extends altos_device implements AltosDevice {
 		return false;
 	}
 
+	public int hashCode() {
+		return getVendor() ^ getProduct() ^ getSerial() ^ getPath().hashCode();
+	}
+
+	public AltosUsbId usb_id() {
+		return new AltosUsbId(getVendor(), getProduct());
+	}
+
+	public String usb_product() {
+		return getName();
+	}
+
+	public boolean equals(Object o) {
+		if (o == null)
+			return false;
+
+		if (!(o instanceof AltosUSBDevice))
+			return false;
+		AltosUSBDevice other = (AltosUSBDevice) o;
+
+		return getVendor() == other.getVendor() &&
+			getProduct() == other.getProduct() &&
+			getSerial() == other.getSerial() &&
+			getPath().equals(other.getPath());
+	}
+
 	static public java.util.List<AltosDevice> list(int product) {
 		if (!AltosUILib.load_library())
 			return null;
