@@ -24,7 +24,7 @@
 
 void main(void)
 {
-	ao_led_init(LEDS_AVAILABLE);
+	ao_led_init();
 	ao_clock_init();
 	ao_task_init();
 	ao_timer_init();
