@@ -700,10 +700,8 @@ ao_radio_test_cmd(void)
 	uint8_t	mode = 2;
 	static uint8_t radio_on;
 	ao_cmd_white();
-	if (ao_cmd_lex_c != '\n') {
-		ao_cmd_decimal();
-		mode = (uint8_t) ao_cmd_lex_u32;
-	}
+	if (ao_cmd_lex_c != '\n')
+		mode = ao_cmd_decimal();
 	mode++;
 	if ((mode & 2) && !radio_on) {
 #if HAS_MONITOR
