@@ -30,13 +30,10 @@
 #define PRINTD(l,...) 
 #endif
 
-uint8_t	ao_mma655x_spi_index = AO_MMA655X_SPI_INDEX;
-
 static void
 ao_mma655x_start(void) {
 	ao_spi_get_bit(AO_MMA655X_CS_PORT,
 		       AO_MMA655X_CS_PIN,
-		       AO_MMA655X_CS,
 		       AO_MMA655X_SPI_INDEX,
 		       AO_SPI_SPEED_FAST);
 }
@@ -45,19 +42,18 @@ static void
 ao_mma655x_stop(void) {
 	ao_spi_put_bit(AO_MMA655X_CS_PORT,
 		       AO_MMA655X_CS_PIN,
-		       AO_MMA655X_CS,
 		       AO_MMA655X_SPI_INDEX);
 }
 
 static void
 ao_mma655x_restart(void) {
 	uint8_t	i;
-	ao_gpio_set(AO_MMA655X_CS_PORT, AO_MMA655X_CS_PIN, AO_MMA655X_CS, 1);
+	ao_gpio_set(AO_MMA655X_CS_PORT, AO_MMA655X_CS_PIN, 1);
 
 	/* Emperical testing on STM32L151 at 32MHz for this delay amount */
 	for (i = 0; i < 10; i++)
 		ao_arch_nop();
-	ao_gpio_set(AO_MMA655X_CS_PORT, AO_MMA655X_CS_PIN, AO_MMA655X_CS, 0);
+	ao_gpio_set(AO_MMA655X_CS_PORT, AO_MMA655X_CS_PIN, 0);
 }
 
 static uint8_t
@@ -261,7 +257,7 @@ ao_mma655x_dump(void)
 	printf ("MMA655X value %d\n", ao_mma655x_current);
 }
 
-__code struct ao_cmds ao_mma655x_cmds[] = {
+const struct ao_cmds ao_mma655x_cmds[] = {
 	{ ao_mma655x_dump,	"A\0Display MMA655X data" },
 	{ 0, NULL },
 };
@@ -279,7 +275,7 @@ ao_mma655x(void)
 	}
 }
 
-static __xdata struct ao_task ao_mma655x_task;
+static struct ao_task ao_mma655x_task;
 
 void
 ao_mma655x_init(void)
