@@ -23,7 +23,7 @@
  * wants to call these functions
  */
 uint8_t
-ao_ee_write_config(uint8_t *buf, uint16_t len) __reentrant
+ao_ee_write_config(uint8_t *buf, uint16_t len) 
 {
 	(void) buf;
 	(void) len;
@@ -31,7 +31,7 @@ ao_ee_write_config(uint8_t *buf, uint16_t len) __reentrant
 }
 
 uint8_t
-ao_ee_read_config(uint8_t *buf, uint16_t len) __reentrant
+ao_ee_read_config(uint8_t *buf, uint16_t len) 
 {
 	ao_xmemset(buf, '\0', len);
 	return 1;
