@@ -41,11 +41,6 @@
 
 #define ao_arch_naked_declare	__attribute__((naked))
 #define ao_arch_naked_define
-#define __pdata
-#define __data
-#define __xdata
-#define __code const
-#define __reentrant
 #define __interrupt(n)
 #define __at(n)
 
@@ -57,28 +52,11 @@
 
 #define ao_arch_interrupt(n)	/* nothing */
 
-#undef putchar
-#undef getchar
-#define putchar(c)	ao_putchar(c)
-#define getchar		ao_getchar
-
-extern void putchar(char c);
-extern char getchar(void);
-extern void ao_avr_stdio_init(void);
-
-
 /*
  * ao_romconfig.c
  */
 
-#define AO_ROMCONFIG_VERSION	2
-
-#define AO_ROMCONFIG_SYMBOL(a) __attribute__((section(".romconfig"))) const
-
-extern const uint16_t ao_romconfig_version;
-extern const uint16_t ao_romconfig_check;
-extern const uint16_t ao_serial_number;
-extern const uint32_t ao_radio_cal;
+#define AO_ROMCONFIG_SYMBOL __attribute__((section(".romconfig"))) const
 
 #define ao_arch_task_members\
 	uint32_t *sp;			/* saved stack pointer */
