@@ -24,7 +24,7 @@
 extern void main(void);
 extern char __stack__;
 extern char __text_start__, __text_end__;
-extern char __data_start__, __data_end__;
+extern char _start__, _end__;
 extern char __bss_start__, __bss_end__;
 
 /* Interrupt functions */
@@ -83,7 +83,7 @@ void start(void)
 #endif
 	/* Set interrupt vector table offset */
 	stm_nvic.vto = (uint32_t) &stm_interrupt_vector;
-	memcpy(&__data_start__, &__text_end__, &__data_end__ - &__data_start__);
+	memcpy(&_start__, &__text_end__, &_end__ - &_start__);
 	memset(&__bss_start__, '\0', &__bss_end__ - &__bss_start__);
 	main();
 }
