@@ -29,7 +29,7 @@ main(void)
 	ao_clock_init();
 
 	ao_task_init();
-	ao_led_init(LEDS_AVAILABLE);
+	ao_led_init();
 	ao_led_on(LEDS_AVAILABLE);
 	ao_timer_init();
 
