@@ -26,6 +26,8 @@
 #define AO_PLLMUL		12
 #define AO_RCC_CFGR_PLLMUL	(STM_RCC_CFGR_PLLMUL_12)
 
+#define AO_CC1200_FOSC		40000000
+
 /* SYSCLK = 32MHz (no need to go faster than CPU) */
 #define AO_PLLDIV		3
 #define AO_RCC_CFGR_PLLDIV	(STM_RCC_CFGR_PLLDIV_3)
@@ -48,10 +50,16 @@
 #define USE_STORAGE_CONFIG	0
 #define HAS_USB			1
 #define HAS_BEEP		1
+#define BEEPER_TIMER		3
+#define BEEPER_CHANNEL		1
+#define BEEPER_PORT		(&stm_gpioc)
+#define BEEPER_PIN		6
 #define HAS_RADIO		1
 #define HAS_RADIO_RATE		1
 #define HAS_TELEMETRY		0
 #define HAS_AES			1
+#define HAS_STATIC_TEST		0
+
 
 #define HAS_SPI_1		0
 #define SPI_1_PA5_PA6_PA7	0
@@ -77,28 +85,23 @@
 #define FAST_TIMER_FREQ		10000	/* .1ms for debouncing */
 
 /*
- * Radio is a cc1120 connected via SPI
+ * Radio is a cc1200 connected via SPI
  */
 
-#define AO_RADIO_CAL_DEFAULT 	0x6ca333
+#define AO_RADIO_CAL_DEFAULT 	5695733
 
 #define AO_FEC_DEBUG		0
-#define AO_CC1120_SPI_CS_PORT	(&stm_gpiod)
-#define AO_CC1120_SPI_CS_PIN	0
-#define AO_CC1120_SPI_BUS	AO_SPI_2_PD1_PD3_PD4
-#define AO_CC1120_SPI		stm_spi2
+#define AO_CC1200_SPI_CS_PORT	(&stm_gpiod)
+#define AO_CC1200_SPI_CS_PIN	0
+#define AO_CC1200_SPI_BUS	AO_SPI_2_PD1_PD3_PD4
+#define AO_CC1200_SPI		stm_spi2
+#define AO_CC1200_SPI_SPEED	AO_SPI_SPEED_FAST
 
-#define AO_CC1120_INT_PORT		(&stm_gpioc)
-#define AO_CC1120_INT_PIN		(15)
-#define AO_CC1120_MCU_WAKEUP_PORT	(&stm_gpiod)
-#define AO_CC1120_MCU_WAKEUP_PIN	(2)
-
-#define AO_CC1120_INT_GPIO	2
-#define AO_CC1120_INT_GPIO_IOCFG	CC1120_IOCFG2
-
-#define AO_CC1120_MARC_GPIO	3
-#define AO_CC1120_MARC_GPIO_IOCFG	CC1120_IOCFG3
+#define AO_CC1200_INT_PORT		(&stm_gpioc)
+#define AO_CC1200_INT_PIN		(15)
 
+#define AO_CC1200_INT_GPIO	2
+#define AO_CC1200_INT_GPIO_IOCFG	CC1200_IOCFG2
 
 #define LOW_LEVEL_DEBUG		0
 
