@@ -1,5 +1,5 @@
 /*
- * Copyright © 2011 Keith Packard <keithp@keithp.com>
+ * Copyright © 2016 Keith Packard <keithp@keithp.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ main(void)
 
 	ao_task_init();
 	ao_serial_init();
-	ao_led_init(LEDS_AVAILABLE);
+	ao_led_init();
 	ao_led_on(LEDS_AVAILABLE);
 	ao_timer_init();
 
@@ -77,7 +77,7 @@ main(void)
 	ao_gps_report_metrum_init();
 	ao_telemetry_init();
 	ao_radio_init();
-	ao_packet_slave_init(FALSE);
+	ao_packet_slave_init(false);
 	ao_igniter_init();
 	ao_companion_init();
 
