@@ -1,5 +1,5 @@
 /*
- * Copyright © 2011 Keith Packard <keithp@keithp.com>
+ * Copyright © 2017 Keith Packard <keithp@keithp.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,49 +16,61 @@
  * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
  */
 
-#include "ao.h"
-#include "ao_pins.h"
+#include <ao.h>
 #include <ao_exti.h>
 
+static void
+ao_check_recovery(void)
+{
+	int	i;
+	ao_enable_input(AO_RECOVERY_PORT, AO_RECOVERY_PIN, AO_RECOVERY_MODE);
+	for (i = 0; i < 100; i++)
+		ao_arch_nop();
+	if (ao_gpio_get(AO_RECOVERY_PORT, AO_RECOVERY_PIN) == AO_RECOVERY_VALUE) {
+		ao_flight_force_idle = 1;
+		ao_force_freq = 1;
+	}
+	ao_gpio_set_mode(AO_RECOVERY_PORT, AO_RECOVERY_PIN, 0);
+	ao_disable_port(AO_RECOVERY_PORT);
+}
+
 void
 main(void)
 {
+	ao_check_recovery();
+
 	ao_clock_init();
-
-#if HAS_STACK_GUARD
-	ao_mpu_init();
-#endif
 	ao_task_init();
-
-	/* Turn on the red LED until the system is stable */
-	ao_led_init(LEDS_AVAILABLE);
-	ao_led_on(AO_LED_RED);
-
 	ao_timer_init();
 
+	ao_dma_init();
 	ao_spi_init();
 	ao_exti_init();
+
 	ao_adc_init();
+
 #if HAS_BEEP
 	ao_beep_init();
 #endif
-	ao_cmd_init();
-#if HAS_MS5607
-	ao_ms5607_init();
+#if HAS_SERIAL_1
+	ao_serial_init();
 #endif
-	ao_storage_init();
+#if HAS_USB
+	ao_usb_init();
+#endif
+	ao_cmd_init();
 
+	ao_ms5607_init();
+
+	ao_storage_init();
 	ao_flight_init();
 	ao_log_init();
 	ao_report_init();
-
-	ao_usb_init();
 	ao_telemetry_init();
 	ao_radio_init();
-	ao_packet_slave_init(TRUE);
-
+	ao_packet_slave_init(true);
 	ao_igniter_init();
-
 	ao_config_init();
+
 	ao_start_scheduler();
 }
